@@ -1,4 +1,4 @@
-runExampleCalcs <-function(trades, csas, colls, simplified = FALSE, OEM = FALSE)
+runExampleCalcs <-function(trades, csas, colls, simplified = FALSE, OEM = FALSE, ignore_margin = FALSE)
 {
   if(length(trades)==length(unlist(lapply(trades,function(x) x$TradeType))))
   {
@@ -35,8 +35,6 @@ runExampleCalcs <-function(trades, csas, colls, simplified = FALSE, OEM = FALSE)
           {
             if(cpties[cpty_counter] %in% unique(unlist(lapply(csas,function(x) x$Counterparty))))
             {
-              
-            
             csa_tradegroup = gsub("[']","",unlist(csas[[i]]$TradeGroups))
             csa_currency = gsub("[']","",unlist(csas[[i]]$Currency))
             
@@ -47,7 +45,9 @@ runExampleCalcs <-function(trades, csas, colls, simplified = FALSE, OEM = FALSE)
             
             trades_tree = CreateTradeGraph(trades_temp[[i]]) 
             trade_ids = sapply(trades_temp[[i]], function(x) x$external_id)
-            MF = csas[[i]]$CalcMF(simplified = simplified)
+            if(ignore_margin)
+            {     MF =1
+            }else {MF = csas[[i]]$CalcMF(simplified = simplified)}
             ext_trade_ids_temp = c(ext_trade_ids_temp, trade_ids)
             # calculating the add-on
             trade_trees[[i]] = CalcAddon(trades_tree, MF, simplified = simplified, OEM = OEM)
@@ -77,15 +77,22 @@ runExampleCalcs <-function(trades, csas, colls, simplified = FALSE, OEM = FALSE)
         # calculating the RC and the V-c amount
         if(i>length(csas))
         {
-          trade_trees[[i]]$`Replacement Cost` <- CalcRC(trades_temp[[i]],simplified = simplified)
+          trade_trees[[i]]$`Replacement Cost` <- CalcRC(trades_temp[[i]],simplified = simplified, ignore_margin = ignore_margin)
         }else
-        {      trade_trees[[i]]$`Replacement Cost` <- CalcRC(trades_temp[[i]], csas[[i]], colls,simplified = simplified)   }
+        {      trade_trees[[i]]$`Replacement Cost` <- CalcRC(trades_temp[[i]], csas[[i]], colls,simplified = simplified, ignore_margin = ignore_margin)   }
         
         # calculating the PFE after multiplying the addon with a factor if V-C<0
-        trade_trees[[i]]$PFE <- CalcPFE(trade_trees[[i]]$`Replacement Cost`$V_C, trade_trees[[i]]$addon, simplified = simplified)
+        trade_trees[[i]]$PFE <- CalcPFE(trade_trees[[i]]$`Replacement Cost`$V_C,trade_trees[[i]]$`Replacement Cost`$V, trade_trees[[i]]$addon, simplified = simplified)
         
         # calculating the Exposure-at-Default
         trade_trees[[i]]$EAD <- CalcEAD(trade_trees[[i]]$`Replacement Cost`$RC,trade_trees[[i]]$PFE)
+        trades_tree_unmmargined = CreateTradeGraph(trades_temp[[i]])
+        trades_tree_unmmargined= CalcAddon(trades_tree_unmmargined, simplified = simplified, OEM = OEM)
+        trades_tree_unmmargined$`Replacement Cost` <- CalcRC(trades_temp[[i]],simplified = simplified, ignore_margin = ignore_margin)
+        trades_tree_unmmargined$PFE <- CalcPFE(trades_tree_unmmargined$`Replacement Cost`$V_C,trades_tree_unmmargined$`Replacement Cost`$V, trades_tree_unmmargined$addon, simplified = simplified)
+        trades_tree_unmmargined$EAD <- CalcEAD(trades_tree_unmmargined$`Replacement Cost`$RC,trades_tree_unmmargined$PFE)
+        
+        trade_trees[[i]]$EAD = min(trades_tree_unmmargined$EAD,trade_trees[[i]]$EAD)   
       }
       trade_trees_all[[cpty_counter]] = trade_trees
     }
@@ -143,15 +150,23 @@ runExampleCalcs <-function(trades, csas, colls, simplified = FALSE, OEM = FALSE)
       # calculating the RC and the V-c amount
       if(i>length(csas))
       {
-        trade_trees[[i]]$`Replacement Cost` <- CalcRC(trades_temp[[i]],simplified = simplified)
+        trade_trees[[i]]$`Replacement Cost` <- CalcRC(trades_temp[[i]],simplified = simplified, ignore_margin = ignore_margin)
       }else
-      {      trade_trees[[i]]$`Replacement Cost` <- CalcRC(trades_temp[[i]], csas[[i]], colls,simplified = simplified)   }
+      {      trade_trees[[i]]$`Replacement Cost` <- CalcRC(trades_temp[[i]], csas[[i]], colls,simplified = simplified, ignore_margin = ignore_margin)   }
       
       # calculating the PFE after multiplying the addon with a factor if V-C<0
-      trade_trees[[i]]$PFE <- CalcPFE(trade_trees[[i]]$`Replacement Cost`$V_C, trade_trees[[i]]$addon, simplified = simplified)
+      trade_trees[[i]]$PFE <- CalcPFE(trade_trees[[i]]$`Replacement Cost`$V_C,trade_trees[[i]]$`Replacement Cost`$V, trade_trees[[i]]$addon, simplified = simplified)
       
       # calculating the Exposure-at-Default
       trade_trees[[i]]$EAD <- CalcEAD(trade_trees[[i]]$`Replacement Cost`$RC,trade_trees[[i]]$PFE)
+      
+      trades_tree_unmmargined = CreateTradeGraph(trades_temp[[i]])
+      trades_tree_unmmargined= CalcAddon(trades_tree_unmmargined, simplified = simplified, OEM = OEM)
+      trades_tree_unmmargined$`Replacement Cost` <- CalcRC(trades_temp[[i]],simplified = simplified, ignore_margin = ignore_margin)
+      trades_tree_unmmargined$PFE <- CalcPFE(trades_tree_unmmargined$`Replacement Cost`$V_C,trades_tree_unmmargined$`Replacement Cost`$V, trades_tree_unmmargined$addon, simplified = simplified)
+      trades_tree_unmmargined$EAD <- CalcEAD(trades_tree_unmmargined$`Replacement Cost`$RC,trades_tree_unmmargined$PFE)
+      
+      trade_trees[[i]]$EAD = min(trades_tree_unmmargined$EAD,trade_trees[[i]]$EAD)   
     }
     return(trade_trees)
   }
